"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GoogleAuthenticationProvider = void 0;
const tslib_1 = require("tslib");
const context_1 = require("@loopback/context");
const core_1 = require("@sourceloop/core");
const node_fetch_1 = tslib_1.__importDefault(require("node-fetch"));
let GoogleAuthenticationProvider = class GoogleAuthenticationProvider {
    constructor(logger) {
        this.logger = logger;
    }
    value() {
        return async (accessToken, req, payload) => this.isAuthenticated(accessToken, req, payload);
    }
    isAuthenticated(accessToken, req, payload) {
        let isAuthenticated = true;
        const googleApiUrl = `${process.env.GOOGLE_TOKEN_INFO_URL}?access_token=${accessToken}`;
        // Using fetch to make the API call
        (0, node_fetch_1.default)(googleApiUrl, {
            method: 'post',
        })
            .then(response => {
            // Check if the response status is OK (200)
            if (!response.ok) {
                isAuthenticated = false;
                this.logger.info(`User is not authenticated to use the application furter.`);
                throw new Error(`HTTP error! Status: ${response.status}`);
            }
            // Parse the JSON response
            return response.json();
        })
            .then(data => {
            if (!('aud' in data) || data.aud !== process.env.GOOGLE_CLIENT_ID) {
                isAuthenticated = false;
            }
        })
            .catch(error => {
            this.logger.error(`Error while logging off from google. Error :: ${error} ${JSON.stringify(error)}`);
        });
        return isAuthenticated;
    }
};
exports.GoogleAuthenticationProvider = GoogleAuthenticationProvider;
exports.GoogleAuthenticationProvider = GoogleAuthenticationProvider = tslib_1.__decorate([
    tslib_1.__param(0, (0, context_1.inject)(core_1.LOGGER.LOGGER_INJECT)),
    tslib_1.__metadata("design:paramtypes", [Object])
], GoogleAuthenticationProvider);
//# sourceMappingURL=google-authentication.provider.js.map