"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ActiveUserFilterBuilderService = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@loopback/core");
const repository_1 = require("@loopback/repository");
const keys_1 = require("../keys");
const repositories_1 = require("../repositories");
let ActiveUserFilterBuilderService = class ActiveUserFilterBuilderService {
    constructor(actorKey, userRepo, userTenantRepo) {
        this.actorKey = actorKey;
        this.userRepo = userRepo;
        this.userTenantRepo = userTenantRepo;
    }
    async buildActiveUsersFilter(filter) {
        let actorIds = [];
        // sonarignore:start
        if (filter.userIdentity === "actorId" /* UserIdentity.ACTOR_ID */) {
            actorIds = filter.userIdentifier;
        }
        else {
            // check if actor is userTenantId
            if (this.actorKey === 'id') {
                const users = await this.userRepo.findAll({
                    where: { username: { inq: filter.userIdentifier } },
                });
                const userIds = users.map(u => { var _a; return (_a = u.id) !== null && _a !== void 0 ? _a : '0'; });
                if (userIds.length <= 0) {
                    return {};
                }
                const userTenants = await this.userTenantRepo.findAll({
                    where: {
                        userId: { inq: userIds },
                    },
                });
                actorIds = userTenants.map(ut => { var _a; return (_a = ut.id) !== null && _a !== void 0 ? _a : '0'; });
                // else actor is userId
            }
            else {
                // get list of user Id based on username
                const users = await this.userRepo.findAll({
                    where: { username: { inq: filter.userIdentifier } },
                });
                actorIds = users.map(u => { var _a; return (_a = u.id) !== null && _a !== void 0 ? _a : '0'; });
            }
        }
        // sonarignore:end
        //include userIds
        if (filter.inclusion) {
            return { actor: { inq: actorIds } };
            //exclude userIds
        }
        else {
            return { actor: { nin: actorIds } };
        }
    }
};
exports.ActiveUserFilterBuilderService = ActiveUserFilterBuilderService;
exports.ActiveUserFilterBuilderService = ActiveUserFilterBuilderService = tslib_1.__decorate([
    (0, core_1.injectable)({ scope: core_1.BindingScope.TRANSIENT }),
    tslib_1.__param(0, (0, core_1.inject)(keys_1.AuthServiceBindings.ActorIdKey)),
    tslib_1.__param(1, (0, repository_1.repository)(repositories_1.UserRepository)),
    tslib_1.__param(2, (0, repository_1.repository)(repositories_1.UserTenantRepository)),
    tslib_1.__metadata("design:paramtypes", [String, repositories_1.UserRepository,
        repositories_1.UserTenantRepository])
], ActiveUserFilterBuilderService);
//# sourceMappingURL=active-user-fliter-builder.service.js.map